@@ -78,7 +78,7 @@ MARSSoptim <- function(MLEobj) {
   } else {
     upper <- control$upper
   }
-  if (control$trace == -1) control$trace <- 0
+  if (control$trace == -1) optim.control$trace <- 0
 
   # The code is used to set things up to use MARSSvectorizeparam to just select inits for the estimated parameters
   # Q=t(chol(Q)%*%chol(Q)); t(chol(Q)) has 0 in upper triangle
@@ -168,7 +168,16 @@ MARSSoptim <- function(MLEobj) {
     pars <- MARSSvectorizeparam(tmp.MLEobj) # now the pars values have been adjusted back to normal scaling
     # now put the estimated values back into the original MLEobj; fixed and free matrices as in original
     MLEobj.return <- MARSSvectorizeparam(MLEobj.return, pars)
-    kf.out <- MARSSkf(MLEobj.return)
+    kf.out <- try(MARSSkf(MLEobj.return), silent = TRUE)
+
+    if (inherits(kf.out, "try-error")) {
+      MLEobj.return$numIter <- optim.output$counts[1]
+      MLEobj.return$logLik <- -1 * optim.output$value
+      MLEobj.return$errors <- c(paste0("\nWARNING: optim() successfully fit the model but ", kf.function, " returned an error with the fitted model. Try MARSSinfo('optimerror54') for insight.", sep = ""), "\nError: ", kf.out[1])
+      MLEobj.return$convergence <- 54
+      MLEobj.return <- MARSSaic(MLEobj.return)
+      kf.out <- NULL
+    }
   } else {
     if (optim.output$convergence == 10) optim.output$message <- c("degeneracy of the Nelder-Mead simplex\n", paste("Function ", kf.function, " used for likelihood calculation.\n", sep = ""), optim.output$message)
     optim.output$counts <- NULL
