@@ -1,5 +1,5 @@
 autoplot.marssPredict <-
-  function(x, include, pi.int = TRUE, decorate = TRUE,
+  function(x, include, decorate = TRUE,
            plot.par = list(), ...) {
     if (!requireNamespace("ggplot2", quietly = TRUE)) {
       stop("ggplot2 is needed for this function to work. Install it via install.packages(\"ggplot2\")",
@@ -9,9 +9,13 @@ autoplot.marssPredict <-
     if (!inherits(x, "marssPredict")) {
       stop("autoplot.marssPredict requires a marssPredict object.", call. = FALSE)
     }
+    if(!is.logical(decorate)){
+      stop("autoplot.marssPredict: decorate must be TRUE/FALSE.", call. = FALSE)
+    }
+    pi.int <- ifelse(decorate, TRUE, FALSE)
     plotpar <- list(
       point.pch = 19, point.col = "blue", point.fill = "blue", point.size = 1,
-      line.col = "black", line.size = 1, line.linetype = "solid",
+      line.col = "black", line.size = 1, line.type = "solid",
       ci.fill = NULL, ci.col = NULL,
       ci.linetype = "blank",
       ci.linesize = 0, ci.alpha = 0.6,
@@ -61,13 +65,11 @@ autoplot.marssPredict <-
     }
 
     if (h == 0) {
-      df <- subset(x$pred, x$t > nx - include + 1)
+      df <- subset(x$pred, x$pred$t >= nx - include + 1)
+      df$.rownames <- factor(df$.rownames, levels=unique(df$.rownames))
+      # Set up the plot
+      plottitle <- paste(ifelse(substr(x$type, 1, 1)=="x", "State", "Data"), x$type, "Predictions")
       p1 <- ggplot2::ggplot(data = df, ggplot2::aes_(~t, ~estimate)) + plotpar[["theme"]]
-      p1 <- p1 +
-        ggplot2::geom_line(linetype = plotpar$line.linetype, color = plotpar$line.col, size = plotpar$line.size) +
-        ggplot2::xlab("Time") + ggplot2::ylab("Estimate") +
-        ggplot2::facet_wrap(~ df$.rownames, scale = "free_y") +
-        ggplot2::ggtitle(paste(ifelse(x$type == "xtT", "State", "Data"), "Predictions"))
       if (pi.int) {
         for (i in length(lev):1) {
           tmp <- df
@@ -79,25 +81,43 @@ autoplot.marssPredict <-
             linetype = plotpar$ci.linetype, size = plotpar$ci.linesize
           )
         }
+        plottitle <- paste(plottitle, switch(x$interval.type, none="", confidence="+ CI", prediction = "+ PI"))
       }
-      if (x$type == "ytT" && decorate) {
-        p1 <- p1 + ggplot2::geom_point(
-          data = df[!is.na(df$y), ], ggplot2::aes_(~t, ~y),
+      p1 <- p1 +
+        ggplot2::geom_line(linetype = plotpar$line.type, color = plotpar$line.col, size = plotpar$line.size) +
+        ggplot2::xlab("Time") + ggplot2::ylab("Estimate") +
+        ggplot2::facet_wrap(~ df$.rownames, scale = "free_y") +
+        ggplot2::ggtitle(plottitle)
+      if (substr(x$type, 1, 1)=="y" && decorate) {
+        p1 <- p1 + ggplot2::geom_point(ggplot2::aes_(~t, ~y),
           shape = plotpar$point.pch, fill = plotpar$point.fill,
-          col = plotpar$point.col, size = plotpar$point.size
+          col = plotpar$point.col, size = plotpar$point.size,
+          na.rm = TRUE
         )
       }
+      note <- NULL
+      if(!all(unlist(lapply(x$newdata, is.null)))){
+        tmp <- names(x$newdata)[!unlist(lapply(x$newdata, function(x){ all(is.na(x))}))]
+        tmp <- tmp[tmp != "t"]
+        note <- paste0("Prediction used newdata: ", paste0(tmp, collapse=", "), ". ")
+      }
+      if(substr(x$type, 1, 1)=="x"){
+        note <- paste(note, "State (x) prediction is the expected value of x(t) conditioned on x(t-1) where x(t-1) is computed conditioned on all the data (xtT) or data up to t-1 (xtt1). This type of state prediction is not commonly used. If you are looking for the estimated states (with CIs), then use autoplot(fit, plot.type='xtT').")
+      }
+      if(!is.null(note)){
+        p1 <- p1 + 
+          ggplot2::labs(caption = paste0(strwrap(note, width=grDevices::dev.size(units = "px")[1]/6), collapse = "\n")) + 
+  ggplot2::theme(plot.caption = ggplot2::element_text(size = 7.5, hjust = 0))
+      }
+      
       return(p1)
     }
     if (h != 0) {
       df <- subset(x$pred, x$t >= nx - include + 1)
+      df$.rownames <- factor(df$.rownames, levels=unique(df$.rownames))
       # set up the plot
+      plottitle <- paste(ifelse(substr(x$type, 1, 1)== "x", "State", "Data"), x$type, "Forecasts")
       p1 <- ggplot2::ggplot(data = df, ggplot2::aes_(~t, ~estimate)) + plotpar[["theme"]]
-      tmp <- df
-      tmp$estimate[tmp$t > nx] <- NA # subset makes facet_wrap fail
-      # make the estimate line
-      p1 <- p1 + ggplot2::geom_line(data = tmp, linetype = plotpar$line.linetype, color = plotpar$line.col, size = plotpar$f.linesize, na.rm = TRUE)
-
       if (pi.int) {
         for (i in length(lev):1) {
           tmp <- df
@@ -111,24 +131,46 @@ autoplot.marssPredict <-
               alpha = plotpar$ci.alpha, fill = plotpar$ci.fill[i], na.rm = TRUE
             )
         }
+        plottitle <- paste(plottitle, switch(x$interval.type, none="", 
+                                             confidence = paste0("+ ", paste0(lev, collapse=", "), "% CI"), 
+                                             prediction = paste0("+ ", paste0(lev, collapse=", "), "% PI")))
       }
+      # make the estimate line
+      tmp <- df
+      tmp$estimate[tmp$t > nx] <- NA # subset makes facet_wrap fail
+      p1 <- p1 + ggplot2::geom_line(data = tmp, 
+                                    linetype = plotpar$line.type, 
+                                    color = plotpar$line.col, 
+                                    size = plotpar$line.size, na.rm = TRUE)
       # Add the forecast line
       tmp <- df
       tmp$estimate[tmp$t <= nx] <- NA
-      p1 <- p1 + ggplot2::geom_line(data = tmp, linetype = plotpar$f.linetype, color = plotpar$f.col, size = plotpar$line.size, na.rm = TRUE)
+      p1 <- p1 + ggplot2::geom_line(data = tmp, linetype = plotpar$f.linetype, color = plotpar$f.col, size = plotpar$f.linesize, na.rm = TRUE)
       # Add labels and titles
       p1 <- p1 +
         ggplot2::xlab("Time") + ggplot2::ylab("Estimate") +
         ggplot2::facet_wrap(~ df$.rownames, scale = "free_y") +
-        ggplot2::ggtitle(paste(ifelse(x$type == "xtT", "State", "Data"), "Predictions"))
+        ggplot2::ggtitle(plottitle)
+      
       # Add the data points
-      if (x$type == "ytT" && decorate) {
+      if (substr(x$type, 1, 1) == "y" && decorate) {
         p1 <- p1 + ggplot2::geom_point(
           data = df, ggplot2::aes_(~t, ~y),
           shape = plotpar$point.pch, fill = plotpar$point.fill,
           col = plotpar$point.col, size = plotpar$point.size, na.rm = TRUE
         )
       }
+      
+      if(!all(unlist(lapply(x$newdata, is.null)))){
+        tmp <- names(x$newdata)[!unlist(lapply(x$newdata, function(x){ all(is.na(x))}))]
+        tmp <- tmp[tmp != "t"]
+        note <- paste("Forecast used newdata in the forecast period:", paste0(tmp, collapse=", "))
+      p1 <- p1 + 
+        ggplot2::labs(caption = paste0(strwrap(note, width=grDevices::dev.size(units = "px")[1]/6), collapse = "\n")) + 
+        ggplot2::theme(plot.caption = ggplot2::element_text(size = 7.5, hjust = 0))
+      }
+      
+      
       return(p1)
     }
   }
